@@ -40,7 +40,7 @@ my $with_url_arg = sub {
 sub twitter_api_method {
     my $caller = shift;
     my $name   = shift;
-    my %options = ( authenticate => $do_auth, @_ );
+    my %options = ( authenticate => $do_auth, datetime_parser => $datetime_parser, @_ );
 
     my $class = Moose::Meta::Class->initialize($caller);
 
@@ -63,10 +63,7 @@ sub twitter_api_method {
         $args->{source} ||= $self->source if $options{add_source};
 
         # save synthetic arguments; don't pass them to Twitter
-        my $synthetic_args = {};
-        for my $k ( $self->_synthetic_args ) {
-            $synthetic_args->{$k} = delete $args->{$k} if exists $args->{$k};
-        }
+        my $synthetic_args = $self->_extract_synthetic_args($args);
 
         my $authenticate = exists $synthetic_args->{authenticate}
                          ? $synthetic_args->{authenticate}
@@ -80,7 +77,7 @@ sub twitter_api_method {
         return $self->_parse_result(
             $self->_authenticated_request($options{method}, $uri, $args, $authenticate),
             $synthetic_args,
-            $datetime_parser,
+            $options{datetime_parser},
         );
     };
 
@@ -114,6 +111,7 @@ has required    => ( isa => 'ArrayRef[Str]', is => 'ro', default => sub { [] } )
 has returns     => ( isa => 'Str', is => 'ro', predicate => 'has_returns' );
 has deprecated  => ( isa => 'Bool', is => 'ro', default => 0 );
 has authenticate => ( isa => 'Bool', is => 'ro', required => 1 );
+has datetime_parser => ( is => 'ro', required => 1 );
 
 # TODO: can MooseX::StrictConstructor be made to work here?
 my %valid_attribute_names = map { $_->init_arg => 1 }
